## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autochangelog
## END: Set by rpmautospec

# Todo:  - Add pkg-config support for libs detection.
#        - Add pkg-config support generated form configure for gpac (same as ffmpeg).
#        - Make it support swscaler enabled ffmpeg (at least test it - upstream).
#        - Submit and import patches upstream.
#        - Fix unused-direct-shlib-dependency on libgpac

#global git           20150924
#global commit  413cd94f24ebf09668cc90434af81729a01e6306
#global date 20211104
#global shortcommit0 %%(c=%%{commit}; echo ${c:0:7})

%if 0%{?el9}
%global _without_jack 1
%global _without_freenect 1
%endif

Name:        gpac
Summary:     MPEG-4 multimedia framework
Version:     2.2.0
Release:     3%{?shortcommit0:.%{date}git%{shortcommit0}}%{?dist}
License:     LGPLv2+
URL:         https://gpac.sourceforge.net/
Source0:     https://github.com/gpac/gpac/archive/v%{version}/gpac-%{version}.tar.gz
#Source0:     https://github.com/gpac/gpac/archive/%{commit}/gpac-%{commit}.tar.gz

Patch0:      gpac-doxygen_195.patch
Patch1:      https://github.com/gpac/gpac/commit/ba14e34dd7a3c4cef5a56962898e9f863dd4b4f3.patch#/ffmpeg6.patch

BuildRequires:  gcc-c++
BuildRequires:  SDL2-devel
BuildRequires:  liba52-devel
BuildRequires:  librsvg2-devel >= 2.5.0
BuildRequires:  libGLU-devel
BuildRequires:  freetype-devel >= 2.1.4
#BuildRequires:  faad2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel >= 1.2.5
BuildRequires:  libmad-devel
BuildRequires:  xvidcore-devel >= 1.0.0
BuildRequires:  ffmpeg-free-devel
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel
BuildRequires:  openjpeg2-devel
BuildRequires:  pulseaudio-libs-devel
BuildRequires:  zlib-devel
BuildRequires:  libogg-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libtheora-devel
BuildRequires:  libXt-devel
BuildRequires:  libXpm-devel
BuildRequires:  libXv-devel
%{!?_without_jack:BuildRequires:  jack-audio-connection-kit-devel}
# Disable optional freenect for i686 multilibs gpac usage
%ifnarch i686
%{!?_without_freenect:BuildRequires:  libfreenect-devel}
%endif
BuildRequires:  xmlrpc-c-devel
BuildRequires:  doxygen
BuildRequires:  graphviz

%description
GPAC is a multimedia framework based on the MPEG-4 Systems standard developed
from scratch in ANSI C.  The original development goal is to provide a clean,
small and flexible alternative to the MPEG-4 Systems reference software.

GPAC features the integration of recent multimedia standards (SVG/SMIL, VRML,
X3D, SWF, 3GPP(2) tools and more) into a single framework. GPAC also features
MPEG-4 Systems encoders/multiplexers, publishing tools for content distribution
for MP4 and 3GPP(2) files and many tools for scene descriptions
(MPEG4 <-> VRML <-> X3D converters, SWF -> MPEG-4, etc).

%package        libs
Summary:        Library for %{name}

%description    libs
The %{name}-libs package contains library for %{name}.


%package  devel
Summary:  Development libraries and files for %{name}
Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description  devel
Development libraries and files for gpac.


%package  doc
Summary:  Documentation for %{name}

%description  doc
Documentation for %{name}.


%package  static
Summary:  Development libraries and files for %{name}
Requires: %{name}-devel%{?_isa} = %{version}-%{release}
Obsoletes: %{name}-devel-static < %{version}-%{release}
Provides:  %{name}-devel-static = %{version}-%{release}

%description  static
Static library for gpac.

%prep
%autosetup -p1
rm -r extra_lib/
pushd share/doc
# Fix encoding warnings
cp -p ipmpx_syntax.bt ipmpx_syntax.bt.origine
iconv -f ISO-8859-1 -t UTF8 ipmpx_syntax.bt.origine >  ipmpx_syntax.bt
touch -r ipmpx_syntax.bt.origine ipmpx_syntax.bt
rm -rf share/doc/ipmpx_syntax.bt.origine
popd
sed -i 's/-O0 $CFLAGS/$CFLAGS/' configure
sed -i 's/-O3 $CFLAGS/$CFLAGS/' configure
sed -i 's/dh_link/ln -s -r/' Makefile


%build
# non-standard script, not compatible with %%configure
./configure \
  --prefix=%{_prefix} \
  --libdir=%{_lib} \
  --mandir=%{_mandir} \
  --extra-cflags="%{optflags} -D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_LARGEFILE_SOURCE=1 -D_GNU_SOURCE=1 $(pkg-config --cflags libavformat)" \
  --X11-path=%{_prefix} \
  --disable-oss-audio \
  --enable-pic \
  --verbose

#Avoid mess with setup.h
cp -p config.h include/gpac

%make_build all 
%make_build sggen

## kwizart - build doxygen doc for devel
pushd share/doc
doxygen
popd

%install
%make_install install-lib
rm -rf %{buildroot}%{_bindir}/Osmo4

#Install generated sggen binaries
for b in MPEG4 X3D; do
  pushd applications/generators/${b}
    install -pm 0755 ${b}Gen %{buildroot}%{_bindir}
  popd
done

#Fix doxygen timestamp
touch -r Changelog share/doc/html-libgpac/*

#config.h like but not only
#Usual multilib bug https://bugzilla.rpmfusion.org/show_bug.cgi?id=270
sed -i -e '/GPAC_CONFIGURATION/d' %{buildroot}%{_includedir}/gpac/configuration.h
touch -r Changelog %{buildroot}%{_includedir}/gpac/*.h
touch -r Changelog %{buildroot}%{_includedir}/gpac/internal/*.h
touch -r Changelog %{buildroot}%{_includedir}/gpac/modules/*.h
rm %{buildroot}%{_includedir}/gpac/config.h


%files
%doc Changelog README.md
%license COPYING
%{_bindir}/gpac
%{_bindir}/MP4Box
%{_bindir}/MPEG4Gen
%{_bindir}/X3DGen
%{_datadir}/applications/gpac.desktop
%{_datadir}/gpac/
%{_datadir}/icons/hicolor/*/apps/gpac.png
%{_mandir}/man1/gpac.1*
%{_mandir}/man1/gpac-filters.1*
%{_mandir}/man1/mp4box.1*

%files libs
%{_libdir}/libgpac.so.12{,.*}
%{_libdir}/gpac/

%files doc
%doc share/doc/html-libgpac/*

%files devel
%doc share/doc/CODING_STYLE share/doc/ipmpx_syntax.bt
%{_includedir}/gpac/
%{_libdir}/libgpac.so
%{_libdir}/pkgconfig/gpac.pc

%files static
%{_libdir}/libgpac_static.a


%changelog
* Tue Mar 14 2023 Yaakov Selkowitz <yselkowi@redhat.com> - 2.2.0-11
- Uncommitted changes

* Mon Mar 13 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-10
- fix

* Tue Feb 28 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-9
- Revert "Apply patch"

* Tue Feb 28 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-8
- Revert "Apply patch"

* Tue Feb 28 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-7
- Revert "Try again"

* Tue Feb 28 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-6
- Try again

* Tue Feb 28 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-5
- Apply patch

* Tue Feb 28 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-4
- Apply patch

* Tue Feb 28 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-3
- Rebuilt for new ffmpeg

* Sat Feb 18 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-2
- add source

* Sat Feb 18 2023 Leigh Scott <leigh123linux@gmail.com> - 2.2.0-1
- Update to 2.2.0

* Sun Aug 07 2022 Sérgio M. Basto <sergio@serjux.com> - 2.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild and
  ffmpeg 5.1

* Sat Feb 26 2022 Leigh Scott <leigh123linux@gmail.com> - 2.0.0-1
- Update to 2.0.0

* Wed Feb 09 2022 Sérgio M. Basto <sergio@serjux.com> - 1.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Nov 09 2021 Leigh Scott <leigh123linux@gmail.com> - 1.0.2-3
- fix

* Tue Nov 09 2021 Leigh Scott <leigh123linux@gmail.com> - 1.0.2-2
- fix

* Tue Nov 09 2021 Leigh Scott <leigh123linux@gmail.com> - 1.0.2-1
- Use git snapshot

* Tue Nov 09 2021 Leigh Scott <leigh123linux@gmail.com> - 1.0.1-5
- Rebuilt for new ffmpeg snapshot

* Mon Aug 02 2021 Leigh Scott <leigh123linux@gmail.com> - 1.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Feb 03 2021 Leigh Scott <leigh123linux@gmail.com> - 1.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 01 2021 Leigh Scott <leigh123linux@gmail.com> - 1.0.1-2
- Rebuilt for new ffmpeg snapshot

* Sun Nov 22 2020 Sérgio M. Basto <sergio@serjux.com> - 1.0.1-1
- Update to 1.0.1

* Mon Aug 17 2020 Leigh Scott <leigh123linux@gmail.com> - 1.0.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Aug 03 2020 Leigh Scott <leigh123linux@gmail.com> - 1.0.0-5
- Make build verbose

* Mon Jul 06 2020 Nicolas Chauvet <kwizart@gmail.com> - 1.0.0-4
- Update changelog

* Mon Jul 06 2020 Nicolas Chauvet <kwizart@gmail.com> - 1.0.0-3
- Disable freenect on i686

* Mon Jul 06 2020 Nicolas Chauvet <kwizart@gmail.com> - 1.0.0-2
- Switch to openjpeg2 instead

* Sun Jul 05 2020 Sérgio M. Basto <sergio@serjux.com> - 1.0.0-1
- Update to 1.0.0 BR SDL2-devel instead SDL-devel Add BR jack-audio-
  connection-kit-devel and libfreenect-devel Remove BR js-devel,
  wxGTK3-devel, gtk+-devel and gtk2-devel

* Thu Mar 12 2020 Leigh Scott <leigh123linux@gmail.com> - 0.8.0-8
- Rebuilt for i686

* Sat Feb 22 2020 leigh123linux <leigh123linux@googlemail.com> - 0.8.0-7
- Rebuild for ffmpeg-4.3 git

* Tue Feb 04 2020 leigh123linux <leigh123linux@googlemail.com> - 0.8.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Dec 17 2019 leigh123linux <leigh123linux@googlemail.com> - 0.8.0-5
- Mass rebuild for x264

* Mon Aug 26 2019 Nicolas Chauvet <kwizart@gmail.com> - 0.8.0-4
- Fix gitignore

* Mon Aug 26 2019 Nicolas Chauvet <kwizart@gmail.com> - 0.8.0-3
- Drop uneeded BR

* Mon Aug 26 2019 Leigh Scott <leigh123linux@googlemail.com> - 0.8.0-2
- Remove unused BuildRequires: js-devel

* Tue Aug 06 2019 Sérgio M. Basto <sergio@serjux.com> - 0.8.0-1
- Update GPAC to 0.8.0

* Tue Aug 06 2019 Leigh Scott <leigh123linux@gmail.com> - 0.7.1-29
- Rebuild for new ffmpeg version

* Tue Mar 12 2019 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-28
- Mass rebuild for x264

* Mon Mar 04 2019 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-27
- Switch to wxGTK3-devel

* Mon Mar 04 2019 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-26
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Nov 26 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-25
- Update changelog

* Mon Nov 26 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-24
- Rename static sub-package

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-23
- Fix BuildRequires

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-22
- Update changelog

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-21
- Clean up

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-20
- Use modern optflags macro

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-19
- make buildroot macro consistent

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-18
- Use new ldconfig scriptlet

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-17
- Use modern buildroot macro

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-16
- Use make macros

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-15
- Drop f26 conditional

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-14
- Drop osmo support

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-13
- Drop mozilla support

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-12
- Use one BuildRequires per line

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-11
- Add missing isa on Requires

* Sun Nov 25 2018 Leigh Scott <leigh123linux@googlemail.com> - 0.7.1-10
- Remove Group tag

* Thu Jul 26 2018 leigh123linux <leigh123linux@googlemail.com> - 0.7.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Mar 08 2018 leigh123linux <leigh123linux@googlemail.com> - 0.7.1-8
- Rebuilt for new ffmpeg snapshot

* Thu Mar 01 2018 leigh123linux <leigh123linux@googlemail.com> - 0.7.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jan 17 2018 leigh123linux <leigh123linux@googlemail.com> - 0.7.1-6
- Try again with ffmpeg build fix as the upstream fix looks bad

* Wed Jan 17 2018 leigh123linux <leigh123linux@googlemail.com> - 0.7.1-5
- Try again with ffmpeg build fix

* Wed Jan 17 2018 leigh123linux <leigh123linux@googlemail.com> - 0.7.1-4
- add ffmpeg build fix

* Wed Jan 17 2018 leigh123linux <leigh123linux@googlemail.com> - 0.7.1-3
- Rebuilt for ffmpeg-3.5 git

* Thu Aug 31 2017 Nicolas Chauvet <kwizart@gmail.com> - 0.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Apr 29 2017 leigh123linux <leigh123linux@googlemail.com> - 0.7.1-1
- Update to 0.7.1

* Sun Mar 19 2017 Nicolas Chauvet <kwizart@gmail.com> - 0.6.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Oct 29 2016 leigh123linux <leigh123linux@googlemail.com> - 0.6.1-3
- Fix build with openssl-1.1.0

* Sat Jul 30 2016 Julian Sikorski <belegdol@fedoraproject.org> - 0.6.1-2
- Rebuilt for ffmpeg-3.1.1

* Thu Mar 10 2016 Sérgio M. Basto <sergio@serjux.com> - 0.6.1-1
- Update to 0.6.1

* Wed Feb 24 2016 Sérgio M. Basto <sergio@serjux.com> - 0.6.0-2
- Update to 0.6.0
- Remove extra_lib directory from sources, like do gpac-snapshot.sh.
- Add License tag.
- Clean defattr(s).

* Wed Feb 24 2016 Sérgio M. Basto <sergio@serjux.com> - 0.6.0-1
- Update to 0.6.0

* Sat Oct 24 2015 Michael Kuhn <suraia@ikkoku.de> - 0.5.2-1
- Update to 0.5.2

* Sat Dec 06 2014 Nicolas Chauvet <kwizart@gmail.com> - 0.5.1-1
- Update gpac to lastest svn

* Sun Oct 19 2014 Sérgio M. Basto <sergio@serjux.com> - 0.5.0-56
- Rebuilt for FFmpeg 2.4.3

* Fri Sep 26 2014 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-55
- * Fri Sep 26 2014 Nicolas Chauvet <kwizart@gmail.com> -
  0.5.0-12.20140915svn - Rebuilt for FFmpeg 2.4.x

* Mon Sep 15 2014 Sérgio M. Basto <sergio@serjux.com> - 0.5.0-54
- * Mon Sep 15 2014 Sérgio Basto <sergio@serjux.com> - 0.5.0-11.20140915svn
  - Update to 20140915 - Some clean ups, fix location of html files.

* Thu Aug 07 2014 Sérgio M. Basto <sergio@serjux.com> - 0.5.0-53
- Rebuilt for ffmpeg-2.3

* Tue Mar 25 2014 Sérgio M. Basto <sergio@serjux.com> - 0.5.0-52
- * Tue Mar 25 2014 Sérgio Basto <sergio@serjux.com> - 0.5.0-9.20130914svn
  - Rebuilt for ffmpeg-2.2

* Tue Nov 05 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-51
- Rebuilt

* Sat Sep 14 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-50
- Fix build

* Tue Aug 20 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-49
- Fix changelog

* Tue Aug 20 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-48
- Define GPAC_FULL_VERSION

* Tue Aug 20 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-47
- Remove merged patches, unbelievable

* Tue Aug 20 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-46
- Update to today's snapshot

* Thu Aug 15 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-45
- * Thu Aug 15 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-5 - Rebuilt
  for FFmpeg 2.0.x

* Sat May 25 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-44
- Rebuilt

* Sun Jan 20 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-43
- Rebuilt for FFmpeg/x264

* Sat Nov 24 2012 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-42
- * Sat Nov 24 2012 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-2 - Rebuilt
  for FFmpeg 1.0

* Sat Jun 23 2012 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-41
- Disable broken js

* Sat Jun 23 2012 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-40
- Update to 0.5.0

* Sat Jun 23 2012 Nicolas Chauvet <kwizart@gmail.com> - 0.5.0-39
- Update to todays snapshot

* Sun Feb 26 2012 Nicolas Chauvet <kwizart@gmail.com>
- Rebuilt

* Wed Feb 22 2012 Nicolas Chauvet <kwizart@gmail.com>
- Rebuilt

* Wed Jan 25 2012 Nicolas Chauvet <kwizart@gmail.com>
- * Wed Jan 25 2012 Nicolas Chauvet <kwizart@gmail.com> -
  0.4.6-0.18.svn20110923 - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Oct 03 2011 Nicolas Chauvet <kwizart@gmail.com>
- Update gpac-soname.patch

* Fri Sep 23 2011 Nicolas Chauvet <kwizart@gmail.com>
- got it

* Fri Sep 23 2011 Nicolas Chauvet <kwizart@gmail.com>
- Is it okay ?

* Fri Sep 23 2011 Nicolas Chauvet <kwizart@gmail.com>
- Hack

* Fri Sep 23 2011 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-31
- Fix svnrevision and update snapshot

* Thu Sep 22 2011 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-30
- Update to 20110915

* Thu Jul 14 2011 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-29
- Rebuild

* Sun Jun 05 2011 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-28
- Rebuild for js-devel (attempt)

* Thu Mar 10 2011 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-27
- Disable openjpeg

* Thu Mar 10 2011 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-26
- Add patch

* Thu Mar 10 2011 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-25
- Rebuilt for openjpeg

* Tue Dec 14 2010 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-24
- Fix include

* Sun Dec 12 2010 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-23
- Attempt to fix rfbz#1551

* Sun Jul 11 2010 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-22
- Fix

* Sat May 29 2010 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-21
- Fix BR

* Sat May 29 2010 Nicolas Chauvet <kwizart@gmail.com> - 0.4.6-20
- Rewrite soname patch that is still needed. - Allow --with osmo
  conditional - Explicitely list binaries.

* Sat Mar 13 2010 Nicolas Chauvet <kwizart@gmail.com>
- Fix CFLAGS for large files rfbz#1116

* Sun Feb 28 2010 Nicolas Chauvet <kwizart@gmail.com>
- Revert previous downgrade

* Sun Feb 28 2010 Nicolas Chauvet <kwizart@gmail.com>
- Fix typo

* Sun Feb 28 2010 Nicolas Chauvet <kwizart@gmail.com>
- Fix #270

* Sun Jan 17 2010 Nicolas Chauvet <kwizart@gmail.com>
- Update to 20100116 - Removed upstreamed patch for system libxml2 - Update
  ffmpeg patch

* Tue Nov 03 2009 Nicolas Chauvet <kwizart@gmail.com>
- Attempt to fix #270

* Sat Sep 19 2009 Nicolas Chauvet <kwizart@gmail.com>
- Update gpac

* Fri Mar 27 2009 Nicolas Chauvet <kwizart@gmail.com>
- Rebuild for faad2 x264

* Tue Mar 24 2009 Nicolas Chauvet <kwizart@gmail.com>
- Revert sequenced patch

* Tue Mar 24 2009 Nicolas Chauvet <kwizart@gmail.com>
- Another one

* Tue Mar 24 2009 Nicolas Chauvet <kwizart@gmail.com>
- Fixes

* Wed Feb 11 2009 Nicolas Chauvet <kwizart@gmail.com>
- Be a little verbose about the issue

* Wed Feb 04 2009 Thorsten Leemhuis <fedora@leemhuis.info>
- * Wed Feb 04 2009 Thorsten Leemhuis <fedora [AT] leemhuis [DOT] info> -
  0.4.5-4 - rebuild for new ssl

* Sun Dec 28 2008 Nicolas Chauvet <kwizart@gmail.com>
- Bump release

* Sun Dec 28 2008 Nicolas Chauvet <kwizart@gmail.com>
- Fix timestamp

* Thu Dec 18 2008 Nicolas Chauvet <kwizart@gmail.com>
- WTF - don't follow ffmpeg configure sample - please

* Wed Dec 17 2008 Nicolas Chauvet <kwizart@gmail.com>
- Update to 0.4.5 Final

* Mon Sep 08 2008 Nicolas Chauvet <kwizart@gmail.com> - 0.4.5-2
- Fix for Large File Support (was livna #2075 )

* Sun Aug 03 2008 Thorsten Leemhuis <fedora@leemhuis.info> - 0.4.5-1
- initial import from livna
